# Django Tools Blog

Django app to add blog to your website

## Installation

1. Install with pip install `django-tools-blog`.

2. Add `djtools.blog` to your INSTALLED_APPS setting like this:
```
INSTALLED_APPS = [
    ...
    'djtools.blog',
]
```
